@@ -74,11 +74,14 @@ class AutoSeller(RedisConnect):
 
         for coin in self.db_seller.values():
             if coin.coin_id == 'USDT':
+                self.usdt = coin.worth
                 continue
             if coin.check():
                 coin.sell()
                 self.session.query(OkexStrategyAutoSeller).filter(
                     OkexStrategyAutoSeller.coin_id == coin.coin_id).delete()
-                self.session.commit()
+            else:
+                self.session.merge(coin)
+            self.session.commit()
         res.update(self.to_json())
         return res
